@@ -342,7 +342,7 @@ delete interfaces {{ int.type }} {{ int.name }}
 {% else %}
 
 {% if int.state == "disabled" -%} 
-set interfaces {{ int.type }} {{ int.name }} disabled
+set interfaces {{ int.type }} {{ int.name }} disable
 {%endif-%}
 
 set interfaces {{ int.type }} {{ int.name }} address {{ int.ip }}{{ int.mask }}
@@ -810,7 +810,7 @@ delete interfaces {{ int.type }} {{ int.name }}
 
 {% if int.state == "disabled" -%} 
 
-set interfaces {{ int.type }} {{ int.name }} disabled
+set interfaces {{ int.type }} {{ int.name }} disable
 {% endif -%}
 set interfaces {{ int.type }} {{ int.name }} address {{ int.ip }}{{ int.mask }}
 
@@ -828,7 +828,7 @@ set interfaces {{ int.type }} {{ int.name }} firewall {{ fw.direction }} name '{
 {% for vif in int.vifs -%}
 
 {% if vif.state == "disabled" -%}
-set interfaces {{ int.type }} {{ int.name }} vif {{ vif.number }} disabled
+set interfaces {{ int.type }} {{ int.name }} vif {{ vif.number }} disable
 {% endif -%}
 
 {% if vif.state == "absent" -%}
